==> alfresco-remote-api-16.37-sources.jar: org/alfresco/rest/api/search/model/Limits.java <==
/*-
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.rest.api.search.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * POJO class representing the query Limits
 **/
public class Limits
{

    private final Integer permissionEvaluationTime;
    private final Integer permissionEvaluationCount;

    @JsonCreator
    public Limits(@JsonProperty("permissionEvaluationTime") Integer permissionEvaluationTime,
                  @JsonProperty("permissionEvaluationCount") Integer permissionEvaluationCount)
    {
        this.permissionEvaluationTime = permissionEvaluationTime;
        this.permissionEvaluationCount = permissionEvaluationCount;
    }

    public Integer getPermissionEvaluationTime()
    {
        return permissionEvaluationTime;
    }

    public Integer getPermissionEvaluationCount()
    {
        return permissionEvaluationCount;
    }
}

==> alfresco-remote-api-23.6.0.30-sources.jar: org/alfresco/rest/api/search/model/Limits.java <==
/*-
 * #%L
 * Alfresco Remote API
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */

package org.alfresco.rest.api.search.model;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * POJO class representing the query Limits
 **/
public class Limits
{

    private final Integer permissionEvaluationTime;
    private final Integer permissionEvaluationCount;
    private final Integer trackTotalHitsLimit;

    @JsonCreator
    public Limits(@JsonProperty("permissionEvaluationTime") Integer permissionEvaluationTime,
                  @JsonProperty("permissionEvaluationCount") Integer permissionEvaluationCount,
                  @JsonProperty("trackTotalHitsLimit") Integer trackTotalHitsLimit)
    {
        this.permissionEvaluationTime = permissionEvaluationTime;
        this.permissionEvaluationCount = permissionEvaluationCount;
        this.trackTotalHitsLimit = trackTotalHitsLimit;
    }

    public Integer getPermissionEvaluationTime()
    {
        return permissionEvaluationTime;
    }

    public Integer getPermissionEvaluationCount()
    {
        return permissionEvaluationCount;
    }

    public Integer getTrackTotalHitsLimit()
    {
        return trackTotalHitsLimit;
    }
}
